<?php
/**
 * Wordsmith functions and definitions
 *
 * Contains all of the Theme's setup functions, custom functions and Theme settings.
 * Some functions are used in the theme as custom template tags.
 * Others are attached to action and filter hooks in WordPress to change core functionality.
 *
 * This file is split into several sub-files, each of which is called below.
 * Refer to each sub-file for documentation of each included function.
 *
 * @package			Wordsmith
 * @copyright		Copyright (C) 2013 Victor Sarabia
 * @license			http://www.gnu.org/licenses/gpl-2.0.html GNU General Public License v2
 * @since			Wordsmith 0.1
 */




/*	==========================================================================
	Start of Wordsmith Functions - Please refrain from editing this section
	========================================================================== */


/**
 * Path to the /functions/ dir
 */
define( 'WORDSMITH_FUNCTIONS_DIR', get_template_directory() . '/functions/' );




/**
 * Include the Theme Setup functions
 *
 * - $content_width
 * - register_nav_menus()
 * - add_theme_support()
 * - register_sidebar()
 */
require_once( WORDSMITH_FUNCTIONS_DIR . 'wordsmith-theme-setup.php' );




/**
 * Include the Navigation Menu functions
 *
 * - Custom Nav Menu Walker class
 * - wordsmith_nav_menu()
 */
require_once( WORDSMITH_FUNCTIONS_DIR . 'wordsmith-navigation.php' );




/**
 * Include Custom Template Tags
 */
require_once( WORDSMITH_FUNCTIONS_DIR . 'wordsmith-template-tags.php' );




/**
 * Include functions hooked to action/filter hooks
 */
require_once( WORDSMITH_FUNCTIONS_DIR . 'wordsmith-hooked-functions.php' );




/**
 * Include the functions used for displaying the comments section
 *
 * - callbacks for wp_list_comments()
 * - wordsmith_comments_pagination()
 * - hook for 'comment_form_defaults'
 */
require_once( WORDSMITH_FUNCTIONS_DIR . 'wordsmith-comments.php' );




/*	==========================================================================
	End of Wordsmith Functions - You can add custom functions below
	========================================================================== */
